@@ -40,6 +40,11 @@ class Moji:
         Male = 'm000'
         '''男生发音'''
 
+    @classmethod
+    def __post_without_proxies(cls, url, data=None, json=None, **kwargs):
+        kwargs['proxies'] = {'http': None, 'https': None}
+        utils.request_post(url, data, json, **kwargs)
+
     @classmethod
     def login(cls, email: str, password: str):
         """
@@ -65,7 +70,7 @@ class Moji:
 
         :param functions: 每个结构为：{'name': API名, 'params': dict类型的参数列表}，可参考union_search方法
         """
-        return utils.request_post('https://api.mojidict.com/parse/functions/union-api', json={
+        return cls.__post_without_proxies('https://api.mojidict.com/parse/functions/union-api', json={
             'functions': functions,
             'g_os': cls.g_os,
             'g_ver': cls.g_ver,
@@ -99,7 +104,7 @@ class Moji:
         if types:
             # 过滤不支持搜索的DataType
             types = [t for t in types if t in Moji.search_types]
-        return utils.request_post('https://api.mojidict.com/parse/functions/search-all', json={
+        return cls.__post_without_proxies('https://api.mojidict.com/parse/functions/search-all', json={
             'text': text,
             'types': types or cls.search_types,
             'g_os': cls.g_os,
@@ -117,7 +122,7 @@ class Moji:
 
         :param text: 输入文本
         """
-        return utils.request_post('https://api.mojidict.com/parse/functions/search_v3', json={
+        return cls.__post_without_proxies('https://api.mojidict.com/parse/functions/search_v3', json={
             'langEnv': 'zh-CN_ja',
             'searchText': text,
             '_ApplicationId': cls._ApplicationId,
@@ -133,7 +138,7 @@ class Moji:
 
         :param text: 输入文本
         """
-        return utils.request_post('https://api.mojidict.com/parse/functions/search-grammar', json={
+        return cls.__post_without_proxies('https://api.mojidict.com/parse/functions/search-grammar', json={
             'limit': 20,
             'text': text,
             'g_os': cls.g_os,
@@ -151,7 +156,7 @@ class Moji:
 
         :param text: 输入文本
         """
-        return utils.request_post('https://api.mojidict.com/parse/functions/search-example', json={
+        return cls.__post_without_proxies('https://api.mojidict.com/parse/functions/search-example', json={
             'limit': 20,
             'text': text,
             'g_os': cls.g_os,
@@ -164,7 +169,7 @@ class Moji:
 
     @classmethod
     def fetch_word(cls, object_id: str) -> dict:
-        return utils.request_post('https://api.mojidict.com/parse/functions/ui-union-apis-word', headers={
+        return cls.__post_without_proxies('https://api.mojidict.com/parse/functions/ui-union-apis-word', headers={
             'X-Parse-Application-Id': cls._ApplicationId,
         }, json={
             'skipAccessories': False,
@@ -182,7 +187,7 @@ class Moji:
         :param object_ids: ID列表
         :return:
         """
-        return utils.request_post('https://api.mojidict.com/parse/functions/nlt-fetchManyLatestWords', json={
+        return cls.__post_without_proxies('https://api.mojidict.com/parse/functions/nlt-fetchManyLatestWords', json={
             'itemsJson': [{'objectId': object_id} for object_id in object_ids],
             'skipAccessories': False,
             'g_os': cls.g_os,
@@ -200,7 +205,7 @@ class Moji:
 
         :param example_id: 例句ID
         """
-        return utils.request_post('https://api.mojidict.com/parse/functions/nlt-fetchExample', json={
+        return cls.__post_without_proxies('https://api.mojidict.com/parse/functions/nlt-fetchExample', json={
             'id': example_id,
             'g_os': cls.g_os,
             'g_ver': cls.g_ver,
@@ -217,7 +222,7 @@ class Moji:
 
         :param ids: ID列表
         """
-        return utils.request_post('https://api.mojidict.com/parse/functions/nlt-fetchManySentences', json={
+        return cls.__post_without_proxies('https://api.mojidict.com/parse/functions/nlt-fetchManySentences', json={
             'ids': ids,
             'withExtra': True,
             'g_os': cls.g_os,
@@ -239,7 +244,7 @@ class Moji:
         """
         if tar_type is cls.DataType.Grammar:
             tar_type = cls.DataType.Word
-        return utils.request_post('https://api.mojidict.com/parse/functions/tts-fetch', json={
+        return cls.__post_without_proxies('https://api.mojidict.com/parse/functions/tts-fetch', json={
             'tarId': tar_id,
             'tarType': tar_type,
             'voiceId': voice_id,
@@ -258,7 +263,7 @@ class Moji:
 
         :param text: 所选文本
         """
-        return utils.request_post('https://api.mojidict.com/parse/functions/word-clickSearch', json={
+        return cls.__post_without_proxies('https://api.mojidict.com/parse/functions/word-clickSearch', json={
             'langEnv': 'zh-CN_ja',
             'searchText': text,
             'g_os': cls.g_os,
